==> bacula-doc_2.0.3.orig.tar.gz: bacula-docs-2.0.3/home-page/fr/pages/professional.php <==
<? require_once("inc/header.php"); ?>
<table>
  <tr>
    <td class="contentTopic">
      Support Professionnel pour Bacula
    </td>
  </tr>
  <tr>
    <td class="content">
      <p>
        Les personnes suivantes sont des entrepreneurs indpendants. Ils ont
        tous travaill avec Bacula et nous sommes heureux de lister leur nom
        ici comme un service, mais sans garanties.
        <br>
        Merci de lire cette courte <a href="?page=listlic">'licence'</a> 
        propos du support professionnel. Tous les noms ont t revus et
        approuvs.
        <br>
        Toutes les adresses email ont t tendues avec un tag 'NOSPAM'. Merci
        de le supprimer avant d'envoyer un email.
      <p>
    </td>
  </tr>
  <tr>
    <td class="content">
      <table align="center">
        <tr><td colspan="3"><hr></hr></td></tr>
        <tr>
          <td colspan="3">
            <img src="images/spacer.gif" width="50px" height="25px">
          </td>
        </tr>
        <tr>
          <td style="font-weight: bold">Alixen</td>
          <td><img src="images/spacer.gif" width="50px" height="1px"></td>
          <td>
            <a href="mailto:infoNOSPAM@alixen.fr">Gilles Polart-Donat</a><br>
            2 rue Jean Rostand<br>
            91893 Orsay CEDEX, France<br>
            +33 01 69 85 24 13<br>
            <br>
            <a href="http://www.alixen.fr">http://www.alixen.fr</a>
          </td>
        </tr>

      <tr><td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td></tr>
      <tr><td colspan="3"><hr></hr></td>
      <tr><td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                      Arden Group Inc
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:rberryNOSPAM@ardengrp.com">Roger Berry</a><br>
                 5026 NE Clackamas<br>
                 Portland, OR 97213 USA<br>
                 +1(971)223-3987<br>
                 <br>
                 <a href="http://www.ardengrp.com">http://www.ardengrp.com</a><br>
              </td>
      </tr>

      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                      Axiom Networking
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:ajordanNOSPAM@draftathome.com">Angus Jordan</a><br>
                 9235 215th St, Langley BC, Canada<br>
                 +1-604-888-6162<br>
                 <br>
                 We offer all types of IT related support services.  Platform support:  Linux,<br>
                 Windows 2000/2003 etc.  Lots of experience with Bacula, DBMail, Nagios,<br>
                 Postfix, Qmail, qpopper, BIND (8/9), and MANY others.<br>
                 <br>
                 <a href="http://www.axiomnetworking.ca">http://www.axiomnetworking.ca</a><br>
              </td>
      </tr>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                      BSDCan
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:danNOSPAM@langille.org">Dan Langille</a><br>
                 Suite 474<br>
                 900 Greenbank Road<br>
                 Ottawa, ON K2J 4P6<br>
                 +1 613 863 9741<br>
                 <br>
                 <a href="http://www.langille.org/">http://www.langille.org/</a>
              </td>
      </tr>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                      Instant Root HB
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:infoNOSPAM@instant-root.com">Info-Mail</a><br>
                 Box 1823 <br>
                 SE-58117 Link&ouml;ping, Sweden<br>
                 <br>
                 Instant Root HB is a company specialized in Unix systems administration, network
                 design and implementation, as well as education in various computer-related fields.<br> 
                 <br>
                 <a href="http://www.instant-root.com">http://www.instant-root.com</a><br>
              </td>
      </tr>

      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                      IT-Service Lehmann
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:infoNOSPAM@its-lehmann.de">Arno Lehmann</a><br>
                  Sandstr. 6<br>
                  49080 Osnabr&uuml;ck<br>
                  Germany<br>
                  +49 (0) 541 5803396<br>
                  +49 (0) 160 92008971 (mobile)<br>
                  <br>
                  Storage, Communication, Backup and Monitoring using 
                  Open-Source solutions.  Services from
                  network design to system administration and
                  user education, with a focus on Small
                  Businesses looking for cost-effective solutions.
                  <br>
                  <a href="http://www.its-lehmann.de">http://www.its-lehmann.de</a>
               </td>
              </td>
      </tr>

      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                 KDB Konsult AB
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:matsNOSPAM@kdb.se">Mats Vilhelmsson</a><br>
                 Tel: +46 708 901042<br>
                 <br>
                 Backup hosting - Internet backups, Bacula training, installations and support.<br>
                 <br>
                 <a href="http://www.kdb.se">http://www.kdb.se</a><br>
              </td>
      </tr>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                      L. Strappazon
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:l.strappazonNOSPAM@free.fre">Ludovic Strappazon</a><br>
                 Strasbourg, France<br>
                 +33 660 954735 <br>
                 <br>
                 I offer engineering services and training around storage and Backup. 
                 Planning and scaling of your hardware installation, Bacula implementation.
              </td>
      </tr>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                  MATRIX-Computer
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                  MATRIX-Computer GmbH<br>
                  Dachauer Str. 44<br>
                  80335 M&uuml;nchen<br>
                  Germany<br>

                  +49-89-922 996 80<br>
                  <br>
                  We are a team of software developers with experience in C++, Windows, PHP, 
                  Linux and more. We have done lots of the Think Tools software.<br>
                  <br>
                  <a href="http://www.matrix-computer.com">http://www.matrix-computer.com</a><br>
              </td>
      </tr>

      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                     NETWAYS GmbH
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:infoNOSPAM@netways.de">NETWAYS GmbH</a><br>
                 Deutschherrnstrasse 47a<br>
                 90429 N&uuml;rnberg<br>
                 Germany<br>
                 <br>
                 Telephone +49 911 92885-0<br>
                 Fax +49 911 92885-77<br>
                 <br>
                 <br>
                 We support our customers managing complex and
                 heterogeneous networks.  Our services and
                 solutions, based on Open Source software, help
                 you run your servers and applications
                 failure-free.  Special focus on Nagios, Bacula,
                 Request Tracker, and cluster solutions.  <br> <a
                 href="http://www.netways.de">http://www.netways.de</a><br>
              </td>
      </tr>


      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                     raptus ag
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:infoNOSPAM@raptus.com">raptus ag</a><br>
                 moderne kommunikation<br>
                 burgweg 1<br>
                 2563 ipsach -- switzerland<br>
                 <br>
                 Telephone +41 (0)32 332 9200<br>
                 Fax +41 (0)32 332 9201<br>
                 <br>
                 <br>
                 Modern communications, Internet projects and IT services since 1996!
                 Specialized in heterogeneous networks (linux, mac, windows) and open 
                 source solutions.
                 <br>
                 <a href="http://www.raptus.com">http://www.raptus.com</a><br>
              </td>
      </tr>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                      Sine Nomine Associates
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:infoNOSPAM@sinenomine.net">Services Sales Dept.</a><br>
                 US:<br>
                 &nbsp;&nbsp;43596 Blacksmith Square <br>
                 &nbsp;&nbsp;Ashburn, VA 20147 USA <br>
                 &nbsp;&nbsp;+1 703 723 6673<br>
                 <br>
                 EMEA:<br>
                 &nbsp;&nbsp;Na Dvorcich 17/Na Vrasni 18<br>
                 &nbsp;&nbsp;CZ - Praha 4, 14000 <br>
                 &nbsp;&nbsp;Czech Republic<br>
                 <br>
                 Design and implementation of system management tools and infrastructure,<br>
                 from small systems to enterprise-wide implementations on global scale.<br>
                 Special focus on Bacula for enterprise-class systems and mainframe.<br>
                 <br>
                 <a href="http://www.sinenomine.net">http://www.sinenomine.net</a><br>
              </td>
      </tr>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                      WinFix.IT
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:JoNOSPAM@WinFix.IT">Jo at WinFix.IT</a><br>
                 <br>
                 &nbsp;&nbsp;In and around Leuven and Brussels (Belgium)
                 <br>
                 &nbsp;&nbsp;+32 (0)478-33 76 27<br>
                 <br>
                 Set up of SAMBA File and Print servers/domain controllers, mail
                 servers (Postfix) with spam/virus killers 
                 (Spamassassin/Amavis/Clamav/BitDefender)
                 and backup (with Bacula of course). Network monitoring with Nagios.
                 <br>
                 <a href="http://www.WinFix.IT">http://www.WinFix.IT</a><br>
              </td>
      </tr>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>


   </table>
   </td>
</tr>
</table>
<? require_once("inc/footer.php"); ?>

==> bacula-doc_2.2.5.orig.tar.gz: bacula-docs-2.2.5/home-page/fr/pages/professional.php <==
<? require_once("inc/header.php"); ?>
<table>
  <tr>
    <td class="contentTopic">
      Support Professionnel pour Bacula
    </td>
  </tr>
  <tr>
    <td class="content">
      <p>
        Les personnes suivantes sont des entrepreneurs indpendants. Ils ont
        tous travaill avec Bacula et nous sommes heureux de lister leur nom
        ici comme un service, mais sans garanties.
        <br>
        Merci de lire cette courte <a href="?page=listlic">'licence'</a> 
        propos du support professionnel. Tous les noms ont t revus et
        approuvs.
        <br>
        Toutes les adresses email ont t tendues avec un tag 'NOSPAM'. Merci
        de le supprimer avant d'envoyer un email.
      <p>
    </td>
  </tr>



<tr>
   <td class="content">
   <table align="center">
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                      Alixen
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:infoNOSPAM@alixen.fr">Gilles Polart-Donat</a><br>
                 2 rue Jean Rostand<br>
                 91893 Orsay CEDEX, France<br>
                 +33 01 69 85 24 13<br>
                 <br>
                 <a href="http://www.alixen.fr">http://www.alixen.fr</a>
              </td>
      </tr>

      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                      Arden Group Inc
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:rberryNOSPAM@ardengrp.com">Roger Berry</a><br>
                 5026 NE Clackamas<br>
                 Portland, OR 97213 USA<br>
                 +1(971)223-3987<br>
                 <br>
                 <a href="http://www.ardengrp.com">http://www.ardengrp.com</a><br>
              </td>
      </tr>

      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                      Axiom Networking
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:ajordanNOSPAM@draftathome.com">Angus Jordan</a><br>
                 9235 215th St, Langley BC, Canada<br>
                 +1-604-888-6162<br>
                 <br>
                 We offer all types of IT related support services.  Platform support:  Linux,<br>
                 Windows 2000/2003 etc.  Lots of experience with Bacula, DBMail, Nagios,<br>
                 Postfix, Qmail, qpopper, BIND (8/9), and MANY others.<br>
                 <br>
                 <a href="http://www.axiomnetworking.ca">http://www.axiomnetworking.ca</a><br>
              </td>
      </tr>

      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                      Bayer Technology Group
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:jbayerNOSPAM@BayerTechnologyGroup.com"> Jonathan B Bayer</a><br>
                Bayer Technology Group, 23 Exeter Rd., East Windsor, NJ 08520 USA<br>
                 +1 (609) 632-1200<br>
                 +1 (609) 658-9408 (mobile)<br>
                 <br>
                 Our focus is on assisting and providing high
                 quality IT services to individuals, small businesses and
                 organizations with computer and information technology needs,
                 but who often don't need or have a budget for a full time IT
                 staff.  We specialize in Desktop systems, Local Area Network
                 (LAN), Internet, Computer Systems Security and Disaster
                 Recovery Planning and Implementation using Microsoft and
                 Linux based solutions.  <br> <br> <a
                 href="http://www.BayerTechnologyGroup.com">http://www.BayerTechnologyGroup.com</a><br>
              </td>
      </tr>


      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                      BSDCan
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:danNOSPAM@langille.org">Dan Langille</a><br>
                 Suite 474<br>
                 900 Greenbank Road<br>
                 Ottawa, ON K2J 4P6<br>
                 +1 613 863 9741<br>
                 <br>
                 <a href="http://www.langille.org/">http://www.langille.org/</a>
              </td>
      </tr>

      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                     Heitor Faria
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:heitor.fariaNOSPAM@serpro.gov.br">Serpro</a><br>
                 Consultoria em Software Libre (Brazil)<br>
                 <br>
                 Telephone +55 71 9196-5270<br>
                 <br>
                 <br>
                 Bacula training, installation and support.
                 <br>
              </td>
      </tr>

      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                      Instant Root HB
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:infoNOSPAM@instant-root.com">Info-Mail</a><br>
                 Box 1823 <br>
                 SE-58117 Link&ouml;ping, Sweden<br>
                 <br>
                 Instant Root HB is a company specialized in Unix systems administration, network
                 design and implementation, as well as education in various computer-related fields.<br> 
                 <br>
                 <a href="http://www.instant-root.com">http://www.instant-root.com</a><br>
              </td>
      </tr>

      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                      IT-Service Lehmann
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:infoNOSPAM@its-lehmann.de">Arno Lehmann</a><br>
                  Sandstr. 6<br>
                  49080 Osnabr&uuml;ck</br>
                  Germany<br>
                  +49 (0) 541 5803396<br>
                  +49 (0) 160 92008971 (mobile)<br>
                  <br>
                  Storage, Communication, Backup and Monitoring using 
                  Open-Source solutions.  Services from
                  network design to system administration and
                  user education, with a focus on Small
                  Businesses looking for cost-effective solutions.
                  <br>
                  <a href="http://www.its-lehmann.de">http://www.its-lehmann.de</a>
               </td>
              </td>
      </tr>

      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                 KDB Konsult AB
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:matsNOSPAM@kdb.se">Mats Vilhelmsson</a><br>
                 Tel: +46 708 901042<br>
                 <br>
                 Backup hosting - Internet backups, Bacula training, installations and support.<br>
                 <br>
                 <a href="http://www.kdb.se">http://www.kdb.se</a><br>
              </td>
      </tr>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                      L. Strappazon
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:l.strappazonNOSPAM@free.fre">Ludovic Strappazon</a><br>
                 Strasbourg, France<br>
                 +33 660 954735 <br>
                 <br>
                 I offer engineering services and training around storage and Backup. 
                 Planning and scaling of your hardware installation, Bacula implementation.
              </td>
      </tr>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                  MATRIX-Computer
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                  MATRIX-Computer GmbH<br>
                  Dachauer Str. 44<br>
                  80335 M&uuml;nchen<br>
                  Germany<br>

                  +49-89-922 996 80<br>
                  <br>
                  We are a team of software developers with experience in C++, Windows, PHP, 
                  Linux and more. We have done lots of the Think Tools software.<br>
                  <br>
                  <a href="http://www.matrix-computer.com">http://www.matrix-computer.com</a><br>
              </td>
      </tr>

      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                     NETWAYS GmbH
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:infoNOSPAM@netways.de">NETWAYS GmbH</a><br>
                 Deutschherrnstrasse 47a<br>
                 90429 N&uuml;rnberg<br>
                 Germany<br>
                 <br>
                 Telephone +49 911 92885-0<br>
                 Fax +49 911 92885-77<br>
                 <br>
                 <br>
                 We support our customers managing complex and
                 heterogeneous networks.  Our services and
                 solutions, based on Open Source software, help
                 you run your servers and applications
                 failure-free.  Special focus on Nagios, Bacula,
                 Request Tracker, and cluster solutions.  <br> <a
                 href="http://www.netways.de">http://www.netways.de</a><br>
              </td>
      </tr>


      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                     raptus ag
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:infoNOSPAM@raptus.com">raptus ag</a><br>
                 moderne kommunikation<br>
                 burgweg 1<br>
                 2563 ipsach -- switzerland<br>
                 <br>
                 Telephone +41 (0)32 332 9200<br>
                 Fax +41 (0)32 332 9201<br>
                 <br>
                 <br>
                 Modern communications, Internet projects and IT services since 1996!
                 Specialized in heterogeneous networks (linux, mac, windows) and open 
                 source solutions.
                 <br>
                 <a href="http://www.raptus.com">http://www.raptus.com</a><br>
              </td>
      </tr>




      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                      Sine Nomine Associates
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:infoNOSPAM@sinenomine.net">Services Sales Dept.</a><br>
                 US:<br>
                 &nbsp;&nbsp;43596 Blacksmith Square <br>
                 &nbsp;&nbsp;Ashburn, VA 20147 USA <br>
                 &nbsp;&nbsp;+1 703 723 6673<br>
                 <br>
                 EMEA:<br>
                 &nbsp;&nbsp;Na Dvorcich 17/Na Vrasni 18<br>
                 &nbsp;&nbsp;CZ - Praha 4, 14000 <br>
                 &nbsp;&nbsp;Czech Republic<br>
                 <br>
                 Design and implementation of system management tools and infrastructure,<br>
                 from small systems to enterprise-wide implementations on global scale.<br>
                 Special focus on Bacula for enterprise-class systems and mainframe.<br>
                 <br>
                 <a href="http://www.sinenomine.net">http://www.sinenomine.net</a><br>
              </td>
      </tr>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                      WinFix.IT
              </td>
              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:JoNOSPAM@WinFix.IT">Jo at WinFix.IT</a><br>
                 <br>
                 &nbsp;&nbsp;In and around Leuven and Brussels (Belgium)
                 <br>
                 &nbsp;&nbsp;+32 (0)478-33 76 27<br>
                 <br>
                 Set up of SAMBA File and Print servers/domain controllers, mail
                 servers (Postfix) with spam/virus killers 
                 (Spamassassin/Amavis/Clamav/BitDefender)
                 and backup (with Bacula of course). Network monitoring with Nagios.
                 <br>
                 <a href="http://www.WinFix.IT">http://www.WinFix.IT</a><br>
              </td>
      </tr>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>

   </table>
   </td>
</tr>
</table>
<? require_once("inc/footer.php"); ?>
